@@ -8,6 +8,7 @@ import shlex
 import subprocess
 import sys
 from collections import OrderedDict
+from os import path
 
 PROJECT_DIRECTORY = os.path.realpath(os.path.curdir)
 
@@ -16,17 +17,20 @@ def get_request():
     COOKIECUTTER = (
         OrderedDict()
     )  # We init the variable to the same type that will be set in the next line.
-    COOKIECUTTER = {{ cookiecutter }}
+    COOKIECUTTER = {{ cookiecutter }}  # pylint: disable=undefined-variable
     AUTHOR = "{{ cookiecutter.author }}"
     AUTHOR_EMAIL = "{{ cookiecutter.author_email }}"
     INITIALIZE_GIT_REPO_FLAG = "{{ cookiecutter.initialize_git_repo|lower }}"
+    add_cli_flag = "{{ cookiecutter.add_cli|lower }}"
 
     request = type('PostGenProjectRequest', (), {
         'cookiecutter': COOKIECUTTER,
         'project_dir': PROJECT_DIRECTORY,
+        'module_name': COOKIECUTTER['pkg_name'],
         'author': AUTHOR,
         'author_email': AUTHOR_EMAIL,
         'initialize_git_repo': {'yes': True}.get(INITIALIZE_GIT_REPO_FLAG, False),
+        'add_cli': {'yes': True}.get(add_cli_flag, False),
     })
 
     return request
@@ -141,11 +145,25 @@ def is_git_repo_clean(project_directory: str):
 
     return False
 
+class PostFileRemovalError(Exception):
+    pass
+
+def post_file_removal(request):
+    files_to_remove = []
+    if not request.add_cli:
+        files_to_remove.extend([
+            path.join(request.project_dir, 'src', request.module_name, 'cli.py'),
+            path.join(request.project_dir, 'src', request.module_name, '__main__.py'),
+        ])
+    for file in files_to_remove:
+        os.remove(file)
+
 
 def _post_hook():
     print('\n --- POST GEN SCRIPT')
     request = get_request()
     print('Computed Templated Vars for Post Script')
+    post_file_removal(request)
     if request.initialize_git_repo:
         try:
             initialize_git_repo(request.project_dir)
